@@ -1,33 +1,41 @@
 """Return the string representation of an array."""
+from __future__ import annotations
+from typing import List, Optional, Union
+
 import numpy
 import numpoly
 
+from ..baseclass import ndpoly, PolyLike
 from ..dispatch import implements
 
 
 @implements(numpy.array_repr)
-def array_repr(arr, max_line_width=None, precision=None, suppress_small=None):
+def array_repr(
+        arr: PolyLike,
+        max_line_width: Optional[int] = None,
+        precision: Optional[int] = None,
+        suppress_small: Optional[bool] = None,
+) -> str:
     """
     Return the string representation of an array.
 
     Args:
-        arr : ndarray
+        arr:
             Input array.
-        max_line_width : int, optional
+        max_line_width:
             Inserts newlines if text is longer than `max_line_width`. Defaults
             to ``numpy.get_printoptions()['linewidth']``.
-        precision : int, optional
+        precision:
             Floating point precision. Defaults to
             ``numpy.get_printoptions()['precision']``.
-        suppress_small : bool, optional
+        suppress_small:
             Represent numbers "very close" to zero as zero; default is False.
             Very close is defined by precision: if the precision is 8, e.g.,
             numbers smaller (in absolute value) than 5e-9 are represented as
             zero. Defaults to ``numpy.get_printoptions()['suppress']``.
 
     Returns:
-        (str):
-            The string representation of an array.
+        The string representation of an array.
 
     Examples:
         >>> q0 = numpoly.variable()
@@ -49,10 +57,6 @@ def array_repr(arr, max_line_width=None, precision=None, suppress_small=None):
     if not arr.size:
         return prefix + "[], dtype=%s" % arr.dtype.name + suffix
 
-    if precision is None:
-        precision = numpy.get_printoptions()["precision"]
-    if suppress_small is None:
-        suppress_small = numpy.get_printoptions()["suppress"]
     arr = to_string(arr, precision=precision, suppress_small=suppress_small)
 
     return prefix + numpy.array2string(
@@ -65,17 +69,28 @@ def array_repr(arr, max_line_width=None, precision=None, suppress_small=None):
     ) + suffix
 
 
-def to_string(poly, precision=None, suppress_small=None):
+def to_string(
+        poly: ndpoly,
+        precision: Optional[float] = None,
+        suppress_small: Optional[bool] = None,
+) -> Union[str, List]:
     """
     Convert numpoly object to string object, or array of string objects.
 
     Args:
-        poly (numpoly.ndpoly):
+        poly:
             Polynomial object to convert to strings.
+        precision:
+            Floating point precision. Defaults to
+            ``numpy.get_printoptions()['precision']``.
+        suppress_small:
+            Represent numbers "very close" to zero as zero; default is False.
+            Very close is defined by precision: if the precision is 8, e.g.,
+            numbers smaller (in absolute value) than 5e-9 are represented as
+            zero. Defaults to ``numpy.get_printoptions()['suppress']``.
 
     Returns:
-        (numpy.ndarray, str):
-            If scalar, a string, or if array, numpy.array with string values.
+        If scalar, a string, or if array, numpy.array with string values.
 
     Examples:
         >>> q0, q1 = numpoly.variable(2)
@@ -87,42 +102,54 @@ def to_string(poly, precision=None, suppress_small=None):
         True
 
     """
-    if poly.shape:
-        return [
-            to_string(
-                poly_, precision=precision, suppress_small=suppress_small)
-            for poly_ in poly
-        ]
+    if precision is None:
+        precision = numpy.get_printoptions()["precision"]
+    if suppress_small is None:
+        suppress_small = numpy.get_printoptions()["suppress"]
 
-    exponents_ = poly.exponents.copy()
+    if poly.shape:
+        return [to_string(poly_, precision=precision,
+                          suppress_small=suppress_small)
+                for poly_ in poly]
+
+    output = _to_string(poly, precision, suppress_small)
+    if output:
+        return "".join(output)
+    return str(numpy.zeros(1, dtype=poly.dtype).item())
+
+
+def _to_string(
+        poly: ndpoly,
+        precision: float,
+        suppress_small: bool,
+) -> List[str]:
+    """Backend for to_string."""
+    exponents = poly.exponents.copy()
     coefficients = poly.coefficients
     options = numpoly.get_options()
-    output = []
+    output: List[str] = []
     indices = numpoly.glexsort(
-        exponents_.T,
+        exponents.T,
         graded=options["display_graded"],
         reverse=options["display_reverse"],
     )
     if options["display_inverse"]:
         indices = indices[::-1]
     for idx in indices:
-        coefficient = coefficients[idx]
-        exponents = exponents_[idx]
 
-        if not coefficient or (
-                suppress_small and
-                abs(coefficient) < 10**-precision  # pylint: disable=invalid-unary-operand-type
-        ):
+        if not coefficients[idx]:
+            continue
+        if suppress_small and abs(coefficients[idx]) < 10**-precision:
             continue
 
-        if coefficient == 1 and any(exponents):
+        if coefficients[idx] == 1 and any(exponents[idx]):
             out = ""
-        elif coefficient == -1 and any(exponents):
+        elif coefficients[idx] == -1 and any(exponents[idx]):
             out = "-"
         else:
-            out = str(coefficient)
+            out = str(coefficients[idx])
 
-        exps_and_names = list(zip(exponents, poly.names))
+        exps_and_names = list(zip(exponents[idx], poly.names))
         for exponent, indeterminant in exps_and_names:
             if exponent:
                 if out not in ("", "-"):
@@ -130,10 +157,8 @@ def to_string(poly, precision=None, suppress_small=None):
                 out += indeterminant
             if exponent > 1:
                 out += options["display_exponent"]+str(exponent)
-        if output and float(coefficient) >= 0:
+        if output and float(coefficients[idx]) >= 0:
             out = "+"+out
         output.append(out)
 
-    if output:
-        return "".join(output)
-    return str(numpy.zeros(1, dtype=poly.dtype).item())
+    return output
