@@ -1,7 +1,11 @@
 """Matrix product of two arrays."""
+from __future__ import annotations
+from typing import Any, Optional
+
 import numpy
 import numpoly
 
+from ..baseclass import ndpoly, PolyLike
 from ..dispatch import implements
 
 ERROR_MESSAGE = """\
@@ -11,23 +15,26 @@ matmul: Input operand %d does not have enough dimensions \
 
 
 @implements(numpy.matmul)
-def matmul(x1, x2, out=None, **kwargs):
+def matmul(
+    x1: PolyLike,
+    x2: PolyLike,
+    out: Optional[ndpoly] = None,
+    **kwargs: Any,
+) -> ndpoly:
     """
     Matrix product of two arrays.
 
     Args:
-        x1, x2 (numpoly.ndpoly):
+        x1, x2:
             Input arrays, scalars not allowed.
-        out (Optional[numpoly.ndpoly]):
-            A location into which the result is stored. If provided, it must have
-            a shape that matches the signature `(n,k),(k,m)->(n,m)`. If not
-            provided or `None`, a freshly-allocated array is returned.
-            n,k,m
+        out:
+            A location into which the result is stored. If provided, it must
+            have a shape that matches the signature `(n,k),(k,m)->(n,m)`.
+            If not provided or `None`, a freshly-allocated array is returned.
 
     Returns:
-        (numpoly.ndpoly):
-            The matrix product of the inputs. This is a scalar only when both
-            x1, x2 are 1-d vectors.
+        The matrix product of the inputs. This is a scalar only when both
+        x1, x2 are 1-d vectors.
 
     Raises:
         ValueError:
@@ -35,7 +42,7 @@ def matmul(x1, x2, out=None, **kwargs):
             the second-to-last dimension of `x2`.
 
     Examples:
-        >>> poly = numpoly.symbols("q:4").reshape(2, 2)
+        >>> poly = numpoly.variable(4).reshape(2, 2)
         >>> poly
         polynomial([[q0, q1],
                     [q2, q3]])
@@ -58,6 +65,5 @@ def matmul(x1, x2, out=None, **kwargs):
     x1 = numpoly.reshape(x1, x1.shape+(1,))
     x2 = numpoly.reshape(x2, x2.shape[:-2]+(1,)+x2.shape[-2:])
     x1, x2 = numpoly.broadcast_arrays(x1, x2)
-    out = numpoly.multiply(x1, x2, out=out, **kwargs)
-    out = numpoly.sum(out, axis=-2)
-    return out
+    out_ = numpoly.multiply(x1, x2, out=out, **kwargs)
+    return numpoly.sum(out_, axis=-2)
