@@ -1,12 +1,21 @@
 """Element-wise maximum of array elements."""
+from __future__ import annotations
+from typing import Any, Optional
+
 import numpy
 import numpoly
 
+from ..baseclass import ndpoly, PolyLike
 from ..dispatch import implements
 
 
 @implements(numpy.maximum)
-def maximum(x1, x2, out=None, **kwargs):
+def maximum(
+    x1: PolyLike,
+    x2: PolyLike,
+    out: Optional[ndpoly] = None,
+    **kwargs: Any,
+) -> ndpoly:
     """
     Element-wise maximum of array elements.
 
@@ -18,17 +27,17 @@ def maximum(x1, x2, out=None, **kwargs):
     The net effect is that NaNs are propagated.
 
     Args:
-        x1, x2 (numpoly.ndpoly):
+        x1, x2:
             The arrays holding the elements to be compared. If ``x1.shape !=
             x2.shape``, they must be broadcastable to a common shape (which
             becomes the shape of the output).
-        out (numpoly.ndarray, Tuple[numpoly.ndarray, numpoly.ndarray], None):
+        out:
             A location into which the result is stored. If provided, it must
             have a shape that the inputs broadcast to. If not provided or
             `None`, a freshly-allocated array is returned. A tuple (possible
             only as a keyword argument) must have length equal to the number of
             outputs.
-        where (Optional[numpy.ndarray]):
+        where:
             This condition is broadcast over the input. At locations where the
             condition is True, the `out` array will be set to the ufunc result.
             Elsewhere, the `out` array will retain its original value. Note
@@ -39,9 +48,8 @@ def maximum(x1, x2, out=None, **kwargs):
             Keyword args passed to numpy.ufunc.
 
     Returns:
-        (numpoly.ndarray):
-            The maximum of `x1` and `x2`, element-wise. This is a scalar if
-            both `x1` and `x2` are scalars.
+        The maximum of `x1` and `x2`, element-wise. This is a scalar if
+        both `x1` and `x2` are scalars.
 
     Examples:
         >>> q0, q1 = numpoly.variable(2)
@@ -59,10 +67,11 @@ def maximum(x1, x2, out=None, **kwargs):
         polynomial(q0+1)
 
     """
+    del out
     x1, x2 = numpoly.align_polynomials(x1, x2)
     coefficients1 = x1.coefficients
     coefficients2 = x2.coefficients
-    out = numpy.zeros(x1.shape, dtype=bool)
+    out_ = numpy.zeros(x1.shape, dtype=bool)
 
     options = numpoly.get_options()
     for idx in numpoly.glexsort(x1.exponents.T, graded=options["sort_graded"],
@@ -70,5 +79,5 @@ def maximum(x1, x2, out=None, **kwargs):
 
         indices = (coefficients1[idx] != 0) | (coefficients2[idx] != 0)
         indices &= coefficients1[idx] != coefficients2[idx]
-        out[indices] = coefficients1[idx][indices] > coefficients2[idx][indices]
-    return numpoly.where(out, x1, x2)
+        out_[indices] = (coefficients1[idx] > coefficients2[idx])[indices]
+    return numpoly.where(out_, x1, x2)
