@@ -1,26 +1,33 @@
 """Return the element-wise square of the input."""
+from __future__ import annotations
+from typing import Any, Optional
 import numpy
-import numpoly
 
+from ..baseclass import ndpoly, PolyLike
 from ..dispatch import implements
 from .multiply import multiply
 
 
 @implements(numpy.square)
-def square(x, out=None, where=True, **kwargs):
+def square(
+    x: PolyLike,
+    out: Optional[ndpoly] = None,
+    where: numpy.typing.ArrayLike = True,
+    **kwargs: Any,
+) -> ndpoly:
     """
     Return the element-wise square of the input.
 
     Args:
-        x (numpoly.ndpoly):
+        x:
             Input data.
-        out (Optional[numpy.ndarray]):
+        out:
             A location into which the result is stored. If provided, it must
             have a shape that the inputs broadcast to. If not provided or
             `None`, a freshly-allocated array is returned. A tuple (possible
             only as a keyword argument) must have length equal to the number of
             outputs.
-        where (Optional[numpy.ndarray]):
+        where:
             This condition is broadcast over the input. At locations where the
             condition is True, the `out` array will be set to the ufunc result.
             Elsewhere, the `out` array will retain its original value. Note
@@ -31,9 +38,8 @@ def square(x, out=None, where=True, **kwargs):
             Keyword args passed to numpy.ufunc.
 
     Returns:
-        out (numpoly.ndpoly):
-            Element-wise `x*x`, of the same shape and dtype as `x`.
-            This is a scalar if `x` is a scalar.
+        Element-wise `x*x`, of the same shape and dtype as `x`.
+        This is a scalar if `x` is a scalar.
 
     Examples:
         >>> numpoly.square([1j, 1])
