@@ -1,9 +1,17 @@
 """Find the lead exponents for each polynomial."""
+from __future__ import annotations
+
 import numpy
 import numpoly
 
+from ..baseclass import PolyLike
 
-def lead_exponent(poly, graded=False, reverse=False):
+
+def lead_exponent(
+        poly: PolyLike,
+        graded: bool = False,
+        reverse: bool = False,
+) -> numpy.ndarray:
     """
     Find the lead exponents for each polynomial.
 
@@ -12,22 +20,21 @@ def lead_exponent(poly, graded=False, reverse=False):
     highest ordering, the elements are sorted using the coefficients.
 
     Args:
-        poly (numpoly.ndpoly):
+        poly:
             Polynomial to locate exponents on.
-        graded (bool):
+        graded:
             Graded sorting, meaning the indices are always sorted by the index
             sum. E.g. ``q0**2*q1**2*q2**2`` has an exponent sum of 6, and will
             therefore be consider larger than both ``q0**3*q1*q2``,
             ``q0*q1**3*q2`` and ``q0*q1*z**3``.
-        reverse (bool):
+        reverse:
             Reverses lexicographical sorting meaning that ``q0*q1**3`` is
             considered bigger than ``q0**3*q1``, instead of the opposite.
 
     Returns:
-        (numpy.ndarray):
-            Integer array with the largest exponents in the polynomials. The
-            shape is ``poly.shape + (len(poly.names),)``. The extra dimension
-            is used to indicate the exponent for the different indeterminants.
+        Integer array with the largest exponents in the polynomials. The
+        shape is ``poly.shape + (len(poly.names),)``. The extra dimension
+        is used to indicate the exponent for the different indeterminants.
 
     Examples:
         >>> q0 = numpoly.variable()
@@ -40,12 +47,13 @@ def lead_exponent(poly, graded=False, reverse=False):
                [0, 0, 1, 1, 0]])
 
     """
-    poly = numpoly.aspolynomial(poly)
-    shape = poly.shape
-    poly = poly.ravel()
-    out = numpy.zeros(poly.shape+(len(poly.names),), dtype=int)
-    if not poly.size:
+    poly_ = numpoly.aspolynomial(poly)
+    shape = poly_.shape
+    poly = poly_.ravel()
+    out = numpy.zeros(poly_.shape+(len(poly_.names),), dtype=int)
+    if not poly_.size:
         return out
-    for idx in numpoly.glexsort(poly.exponents.T, graded=graded, reverse=reverse):
-        out[poly.coefficients[idx] != 0] = poly.exponents[idx]
-    return out.reshape(shape+(len(poly.names),))
+    for idx in numpoly.glexsort(
+            poly_.exponents.T, graded=graded, reverse=reverse):
+        out[poly_.coefficients[idx] != 0] = poly_.exponents[idx]
+    return out.reshape(shape+(len(poly_.names),))
